Changelog
============


0.2.0 (2022-04-25)
------------

Changed
~~~~~~~~~~~~

* Reducing McCabe complexity requirements. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Changing branding. [Luis Alejandro Martínez Faneyth]

* Adding support for python 3.11. [Luis Alejandro Martínez Faneyth]

* Updating python version. [Luis Alejandro Martínez Faneyth]

* Updating python versions. [Luis Alejandro Martínez Faneyth]

* Removing support for pypy3. [Luis Alejandro Martínez Faneyth]

* Updating coverage version. [Luis Alejandro Martínez Faneyth]

* Updating coveralls. [Luis Alejandro Martínez Faneyth]

* Changing action day. [Luis Alejandro Martínez Faneyth]

* Removing support for python 3.5 and 3.6. [Luis Alejandro Martínez Faneyth]

* Adjusting cron to weekly basis. [Luis Alejandro Martínez Faneyth]

* Increasing number of pr events for github actions. [Luis Alejandro Martínez Faneyth]

* Disabling dependency update for pip and setuptools. [Luis Alejandro Martínez Faneyth]

* Disabling dependency update for pip and setuptools. [FIX] Fixing coveralls send. [Luis Alejandro Martínez Faneyth]

* Improving graphic image. [Luis Alejandro Martínez Faneyth]

* Migrating Travis to Github Actions. [Luis Alejandro Martínez Faneyth]

* Migrating Travis to Github Actions. [Luis Alejandro Martínez Faneyth]

* Adding docker login. [Luis Alejandro Martínez Faneyth]

* Adding support for python 3.7. [Luis Alejandro Martínez Faneyth]


Fixed
~~~~~~~~~~~~

* Fixing code quality build. [Luis Alejandro Martínez Faneyth]

* Fixing github builds. [Luis Alejandro Martínez Faneyth]

* Fixing pull request permissions. [Luis Alejandro Martínez Faneyth]

* Fixing Github Actions workflow. [Luis Alejandro Martínez Faneyth]


Other
~~~~~~~~~~~~

* Bump virtualenv from 20.14.0 to 20.14.1. [dependabot[bot]]

* Bump setuptools from 62.0.0 to 62.1.0. [dependabot[bot]]

* Bump tox from 3.24.5 to 3.25.0. [dependabot[bot]]

* Bump hmarr/auto-approve-action from 2.1.0 to 2.2.1. [dependabot[bot]]

* Bump setuptools from 61.3.0 to 62.0.0. [dependabot[bot]]

* Bump setuptools from 61.0.0 to 61.3.0. [dependabot[bot]]

* Bump virtualenv from 20.13.4 to 20.14.0. [dependabot[bot]]

* Bump virtualenv from 20.13.3 to 20.13.4. [dependabot[bot]]

* Bump setuptools from 60.10.0 to 61.0.0. [dependabot[bot]]

* Bump setuptools from 60.9.3 to 60.10.0. [dependabot[bot]]

* Bump pip from 22.0.3 to 22.0.4. [dependabot[bot]]

* Bump virtualenv from 20.13.2 to 20.13.3. [dependabot[bot]]

* Bump actions/checkout from 2 to 3. [dependabot[bot]]

* Bump actions/setup-python from 2 to 3. [dependabot[bot]]

* Bump coverage from 6.3.1 to 6.3.2. [dependabot[bot]]

* Bump setuptools from 60.9.2 to 60.9.3. [dependabot[bot]]

* Bump virtualenv from 20.13.1 to 20.13.2. [dependabot[bot]]

* Bump actions/github-script from 5 to 6. [dependabot[bot]]

* Bump setuptools from 60.8.2 to 60.9.2. [dependabot[bot]]

* Bump virtualenv from 20.13.0 to 20.13.1. [dependabot[bot]]

* Bump setuptools from 60.7.1 to 60.8.2. [dependabot[bot]]

* Bump pip from 21.3.1 to 22.0.3. [dependabot[bot]]

* Bump coverage from 6.3 to 6.3.1. [dependabot[bot]]

* Bump setuptools from 60.5.0 to 60.7.1. [dependabot[bot]]

* Bump coverage from 6.2 to 6.3. [dependabot[bot]]

* Bump setuptools from 60.0.5 to 60.5.0. [dependabot[bot]]

* Bump tox from 3.24.4 to 3.24.5. [dependabot[bot]]

* Bump virtualenv from 20.10.0 to 20.13.0. [dependabot[bot]]

* Bump setuptools from 59.6.0 to 60.0.5. [dependabot[bot]]

* Bump setuptools from 59.5.0 to 59.6.0. [dependabot[bot]]

* Bump setuptools from 59.4.0 to 59.5.0. [dependabot[bot]]

* Bump setuptools from 59.2.0 to 59.4.0. [dependabot[bot]]

* Bump coverage from 6.1.2 to 6.2. [dependabot[bot]]

* Bump setuptools from 59.1.1 to 59.2.0. [dependabot[bot]]

* Bump setuptools from 58.5.3 to 59.1.1. [dependabot[bot]]

* Bump hmarr/auto-approve-action from 2.0.0 to 2.1.0. [dependabot[bot]]

* Bump pip from 21.2.4 to 21.3.1. [dependabot[bot]]

* Bump setuptools from 58.2.0 to 58.5.3. [dependabot[bot]]

* Bump virtualenv from 20.8.1 to 20.10.0. [dependabot[bot]]

* Bump flake8 from 3.9.2 to 4.0.1. [dependabot[bot]]

* Bump tox from 3.24.3 to 3.24.4. [dependabot[bot]]

* Bump coverage from 5.5 to 6.0.1. [dependabot[bot]]

* Bump setuptools from 58.1.0 to 58.2.0. [dependabot[bot]]

* Bump virtualenv from 20.7.2 to 20.8.1. [dependabot[bot]]

* Bump setuptools from 58.0.4 to 58.1.0. [dependabot[bot]]

* Bump setuptools from 58.0.0 to 58.0.4. [dependabot[bot]]

* Bump setuptools from 57.4.0 to 58.0.0. [dependabot[bot]]

* Bump tox from 3.24.1 to 3.24.3. [dependabot[bot]]

* Bump virtualenv from 20.7.0 to 20.7.2. [dependabot[bot]]

* Bump pip from 21.2.3 to 21.2.4. [dependabot[bot]]

* Bump pip from 21.2.2 to 21.2.3. [dependabot[bot]]

* Bump pip from 21.2.1 to 21.2.2. [dependabot[bot]]

* Bump virtualenv from 20.6.0 to 20.7.0. [dependabot[bot]]

* Bump tox from 3.24.0 to 3.24.1. [dependabot[bot]]

* Bump pip from 21.1.3 to 21.2.1. [dependabot[bot]]

* Bump coveralls from 3.1.0 to 3.2.0. [dependabot[bot]]

* Bump setuptools from 57.1.0 to 57.4.0. [dependabot[bot]]

* Bump virtualenv from 20.4.7 to 20.6.0. [dependabot[bot]]

* Bump tox from 3.23.1 to 3.24.0. [dependabot[bot]]

* Bump setuptools from 57.0.0 to 57.1.0. [dependabot[bot]]

* Bump pip from 21.1.2 to 21.1.3. [dependabot[bot]]

* Bump coveralls from 3.0.1 to 3.1.0. [dependabot[bot]]

* Bump virtualenv from 20.4.6 to 20.4.7. [dependabot[bot]]

* Bump setuptools from 56.2.0 to 57.0.0. [dependabot[bot]]

* Bump pydocstyle from 6.0.0 to 6.1.1. [dependabot[bot]]

* Bump pip from 21.1.1 to 21.1.2. [dependabot[bot]]

* Bump flake8 from 3.9.1 to 3.9.2. [dependabot[bot]]

* Bump tox from 3.23.0 to 3.23.1. [dependabot[bot]]

* Bump virtualenv from 20.4.4 to 20.4.6. [dependabot[bot]]

* Bump setuptools from 56.0.0 to 56.2.0. [dependabot[bot]]

* Bump pip from 21.1 to 21.1.1. [dependabot[bot]]

* Bump pip from 20.3 to 21.1. [dependabot[bot]]

* Bump virtualenv from 20.4.3 to 20.4.4. [dependabot[bot]]

* Bump flake8 from 3.9.0 to 3.9.1. [dependabot[bot]]

* Bump setuptools from 50.3.2 to 56.0.0. [dependabot[bot]]

* Bump pydocstyle from 5.1.1 to 6.0.0. [dependabot[bot]]

* Bump virtualenv from 20.4.2 to 20.4.3. [dependabot[bot]]

* Bump flake8 from 3.8.4 to 3.9.0. [dependabot[bot]]

* Bump tox from 3.22.0 to 3.23.0. [dependabot[bot]]

* Bump coveralls from 3.0.0 to 3.0.1. [dependabot[bot]]

* Bump coverage from 5.4 to 5.5. [dependabot[bot]]

* Bump tox from 3.21.4 to 3.22.0. [dependabot[bot]]

* Bump tox from 3.20.1 to 3.21.4. [dependabot[bot]]

* Bump virtualenv from 20.2.1 to 20.4.2. [dependabot[bot]]

* Bump coveralls from 2.2.0 to 3.0.0. [dependabot[bot]]

* Bump coverage from 5.3 to 5.4. [dependabot[bot]]

* Scheduled monthly dependency update for December (#58) [pyup.io bot]

* Scheduled monthly dependency update for September (#55) [pyup.io bot]

* Scheduled monthly dependency update for August (#54) [pyup.io bot]

* Scheduled monthly dependency update for July (#53) [pyup.io bot]

* Scheduled monthly dependency update for May (#51) [pyup.io bot]

* Scheduled monthly dependency update for April (#50) [pyup.io bot]

* Scheduled monthly dependency update for March (#49) [pyup.io bot]

* Scheduled monthly dependency update for February (#48) [pyup.io bot]


0.1.20 (2020-01-18)
------------

Changed
~~~~~~~~~~~~

* Adding python 3.7 support. [Luis Alejandro Martínez Faneyth]

* Removing support for python 2.7 and 3.4. Adding support for python 3.8 and PyPy3. [Luis Alejandro Martínez Faneyth]

* Improving docstrings. [Luis Alejandro Martínez Faneyth]

* Changing branding. [Luis Alejandro Martínez Faneyth]


Other
~~~~~~~~~~~~

* Scheduled monthly dependency update for November (#47) [pyup.io bot]

* Scheduled monthly dependency update for October (#46) [pyup.io bot]

* Scheduled monthly dependency update for September (#45) [pyup.io bot]

* Scheduled monthly dependency update for August (#44) [pyup.io bot]

* Scheduled monthly dependency update for July (#43) [pyup.io bot]

* Scheduled monthly dependency update for March (#39) [pyup.io bot]

* Scheduled monthly dependency update for February (#38) [pyup.io bot]

* Scheduled monthly dependency update for December (#36) [pyup.io bot]


0.1.19 (2018-12-12)
------------

Changed
~~~~~~~~~~~~

* Removing support for python 2.6 & 3.2. [Luis Alejandro Martínez Faneyth]


Other
~~~~~~~~~~~~

* Scheduled monthly dependency update for August (#32) [pyup.io bot]

* Scheduled monthly dependency update for June (#31) [pyup.io bot]

* Scheduled monthly dependency update for May (#30) [pyup.io bot]

* Scheduled monthly dependency update for April (#28) [pyup.io bot]

* Scheduled monthly dependency update for March (#27) [pyup.io bot]

* Scheduled monthly dependency update for February (#26) [pyup.io bot]

* Scheduled monthly dependency update for January (#25) [pyup.io bot]

* Scheduled monthly dependency update for December (#24) [pyup.io bot]

* Scheduled monthly dependency update for November (#23) [pyup.io bot]

* Scheduled monthly dependency update for October (#22) [pyup.io bot]

* Scheduled monthly dependency update for September (#21) [pyup.io bot]


0.1.18 (2018-04-18)
------------

Fixed
~~~~~~~~~~~~

* Removing conditional dependencies from requirements.txt because it is not supported for instal_requires with setuptools < 36.2.1, so it breakes py26 and py32 tests. [Luis Alejandro Martínez Faneyth]


0.1.17 (2018-04-15)
------------

Fixed
~~~~~~~~~~~~

* Fixing python 3.2 support. [Luis Alejandro Martínez Faneyth]


0.1.16 (2018-04-14)
------------

Fixed
~~~~~~~~~~~~

* Pinning versions of software to avoid CI breaks over time. [Luis Alejandro Martínez Faneyth]

* Fixing PEP8 styleguide. [Luis Alejandro Martínez Faneyth]


Other
~~~~~~~~~~~~

* Add Gitter badge (#29) [The Gitter Badger]


0.1.15 (2017-08-02)
------------

Changed
~~~~~~~~~~~~

* Adding development tools to requirements. [Luis Alejandro Martínez Faneyth]


0.1.14 (2017-08-02)
------------

Changed
~~~~~~~~~~~~

* Adding pyup configuration. [Luis Alejandro Martínez Faneyth]


0.1.13 (2017-08-02)
------------

Changed
~~~~~~~~~~~~

* Improving parsing of requirements for setuptools. [Luis Alejandro Martínez Faneyth]

* Adjusting version of setuptools for python 2.6. [Luis Alejandro martínez Faneyth]


0.1.12 (2017-07-17)
------------

Changed
~~~~~~~~~~~~

* Adjusting environment markers for different python versions. [Luis Alejandro martínez Faneyth]

* Removing rq.filter notation. [Luis Alejandro martínez Faneyth]

* Adding support for pyup. [Luis Alejandro martínez Faneyth]

* Migrating to environment markers in requirements for simpler management. [Luis Alejandro martínez Faneyth]

* Improving README. [Luis Alejandro martínez Faneyth]


Fixed
~~~~~~~~~~~~

* Fixing pydocstyle tests. [Luis Alejandro martínez Faneyth]


0.1.11 (2017-05-20)
------------

Fixed
~~~~~~~~~~~~

* Fixing python 3.5+ support. [Luis Alejandro Martínez Faneyth]


0.1.10 (2017-05-19)
------------

Fixed
~~~~~~~~~~~~

* Fixing python 3.2 support. [Luis Alejandro Martínez Faneyth]

* Fixing python 3.2 tests. [Luis Alejandro Martínez Faneyth]


0.1.8 (2017-05-19)
------------

Fixed
~~~~~~~~~~~~

* Fixing python 3.5+ support. [Luis Alejandro Martínez Faneyth]


0.1.7 (2017-01-16)
------------

Fixed
~~~~~~~~~~~~

* Hotfix: Fixing Travis build because documentation typo. [Luis Alejandro Martínez Faneyth]


0.1.6 (2017-01-16)
------------

Changed
~~~~~~~~~~~~

* Improving python 3 compatibility. [REF] Renaming pipsalabim.core.util to pipsalabim.core.utils. [Luis Alejandro Martínez Faneyth]


0.1.5 (2017-01-16)
------------

Fixed
~~~~~~~~~~~~

* Fixing python3 compatibility. [Luis Alejandro Martínez Faneyth]


0.1.4 (2017-01-15)
------------

Changed
~~~~~~~~~~~~

* Fixing python 2.6 support on the logger module (closes #11). [ADD] Implementing functional test on .travis.yml. [Luis Alejandro Martínez Faneyth]


Fixed
~~~~~~~~~~~~

* Fixing testing for python 3.2 and 2.6. [Luis Alejandro Martínez Faneyth]


Other
~~~~~~~~~~~~

* New: dev: Adding support to python 2.6 (closes #10). chg: dev: Removing configurations for codeclimate. [Luis Alejandro Martínez Faneyth]


0.1.3 (2017-01-04)
------------

Added
~~~~~~~~~~~~

* Adding gitchangelog configuration file. [Luis Alejandro Martínez Faneyth]

* Adding support to python 2.6 (closes #10). [Luis Alejandro Martínez Faneyth]


Changed
~~~~~~~~~~~~

* Adding new changelog entries. [Luis Alejandro Martínez Faneyth]


Fixed
~~~~~~~~~~~~

* Fixing testing for python 3.2 and 2.6. [Luis Alejandro Martínez Faneyth]

* Fixing bumpversion config. [Luis Alejandro Martínez Faneyth]

* Fixing typo. [Luis Alejandro Martínez Faneyth]


Other
~~~~~~~~~~~~

* Bump version: 0.1.0 → 0.1.1. [Luis Alejandro Martínez Faneyth]


0.1.2 (2017-01-04)
------------

Added
~~~~~~~~~~~~

* Adding gitchangelog configuration file. [Luis Alejandro Martínez Faneyth]

* Adding support to python 2.6 (closes #10). [Luis Alejandro Martínez Faneyth]


0.1.1 (2016-11-24)
------------

Added
~~~~~~~~~~~~

* Adding Contributor License Agreement. [Luis Alejandro Martínez Faneyth]


Changed
~~~~~~~~~~~~

* Adding new changelog entries. [Luis Alejandro Martínez Faneyth]


Fixed
~~~~~~~~~~~~

* Fixing bumpversion config. [Luis Alejandro Martínez Faneyth]

* Fixing typo. [Luis Alejandro Martínez Faneyth]

* Catching exceptions on package discovery as described in #3. [REF] Using find_packages from setuptools to discover packages. [Luis Alejandro Martínez Faneyth]


Other
~~~~~~~~~~~~

* Bump version: 0.1.0 → 0.1.1. [Luis Alejandro Martínez Faneyth]


0.1.0 (2016-11-23)
------------

Changed
~~~~~~~~~~~~

* Improving README. [Luis Alejandro Martínez Faneyth]

* Improving RST markup. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [REF] Configuring codeclimate. [Luis Alejandro Martínez Faneyth]

* Completing API documentation. [REF] Finishing commandline programming. [Luis Alejandro Martínez Faneyth]

* Temporarily increasing McCabe index to 20 to pass tests. [REF] Updating requirements versions. [REF] Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Correcting code style. [Luis Alejandro Martínez Faneyth]

* Improving documentation of functions. [REF] Porting snakefood's code to python 3.x. [REF] Various coe style corrections. [Luis Alejandro Martínez Faneyth]

* Adding code from snakefood because it doesn't support py3k. [REF] Fixing PEP8 errors. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [REF] Adding download progress to "update" command. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [REF] Updating visual style. [REF] Reorganizing code. [Luis Alejandro Martínez Faneyth]

* Updating visual style. [Luis Alejandro Martínez Faneyth]

* General refactoring of structure and code. [ADD] Adding projecto boilerplate. [ADD] Programming of "guess" command. [ADD] Adding visual style. [Luis Alejandro Martínez Faneyth]


Fixed
~~~~~~~~~~~~

* Correcting minor issues. [Luis Alejandro Martínez Faneyth]

* Fixing typo. [Luis Alejandro Martínez Faneyth]


Removed
~~~~~~~~~~~~

* [DEL] Removing unnecessary tests. [REF] Reorganizing code. [REF] Documenting functions. [REF] Starting some unit tests. [Luis Alejandro Martínez Faneyth]


Other
~~~~~~~~~~~~

* 0.1.0 release. [Luis Alejandro Martínez Faneyth]

* Add Gitter badge. [The Gitter Badger]

* Initial commit. [Luis Alejandro Martínez Faneyth]

